<?php $TRANSLATIONS = array(
"Pictures" => "Obrázky",
"Shared by" => "Sdílí",
"Share" => "Sdílet",
"The \"Image Viewer\" application also need to be enabled to use this application." => "Aplikace \"Prohlížeč obrázků\" musí být také povolena pro použití této aplikace."
);
